package com.os.ems.base.controller;

import java.util.List;
import java.util.Map;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.os.common.annotation.Log;
import com.os.common.core.controller.BaseController;
import com.os.common.core.domain.AjaxResult;
import com.os.common.enums.BusinessType;
import com.os.ems.base.domain.EmsAlarmActionStep;
import com.os.ems.base.service.IEmsAlarmActionStepService;
import com.os.common.utils.poi.ExcelUtil;
import com.os.common.core.page.TableDataInfo;

/**
 * 报警规则具体措施步骤Controller
 * 
 * @author zch
 * @date 2025-05-29
 */
@RestController
@RequestMapping("/ems/base/emsAlarmActionStep")
public class EmsAlarmActionStepController extends BaseController
{
    @Autowired
    private IEmsAlarmActionStepService emsAlarmActionStepService;

    /**
     * 查询报警规则具体措施步骤列表
     */
    @PreAuthorize("@ss.hasPermi('ems/base:emsAlarmActionStep:list')")
    @GetMapping("/list")
    public TableDataInfo list(EmsAlarmActionStep emsAlarmActionStep)
    {
        startPage();
        List<EmsAlarmActionStep> list = emsAlarmActionStepService.selectEmsAlarmActionStepList(emsAlarmActionStep);
        return getDataTable(list);
    }

    /**
     * 导出报警规则具体措施步骤列表
     */
    @PreAuthorize("@ss.hasPermi('ems/base:emsAlarmActionStep:export')")
    @Log(title = "报警规则具体措施步骤", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, EmsAlarmActionStep emsAlarmActionStep)
    {
        List<EmsAlarmActionStep> list = emsAlarmActionStepService.selectEmsAlarmActionStepList(emsAlarmActionStep);
        ExcelUtil<EmsAlarmActionStep> util = new ExcelUtil<EmsAlarmActionStep>(EmsAlarmActionStep.class);
        util.exportExcel(response, list, "报警规则具体措施步骤数据");
    }

    /**
     * 获取报警规则具体措施步骤详细信息
     */
    @PreAuthorize("@ss.hasPermi('ems/base:emsAlarmActionStep:query')")
    @GetMapping(value = "/{objId}")
    public AjaxResult getInfo(@PathVariable("objId") String objId)
    {
        return success(emsAlarmActionStepService.selectEmsAlarmActionStepByObjId(objId));
    }

    /**
     * 根据报警规则ID查询措施步骤列表（包含图片）
     */
    @PreAuthorize("@ss.hasPermi('ems/base:emsAlarmActionStep:query')")
    @GetMapping(value = "/rule/{ruleObjId}")
    public AjaxResult getStepsByRuleId(@PathVariable("ruleObjId") String ruleObjId)
    {
        List<EmsAlarmActionStep> steps = emsAlarmActionStepService.selectEmsAlarmActionStepByRuleObjId(ruleObjId);
        return success(steps);
    }

    /**
     * 新增报警规则具体措施步骤
     */
    @PreAuthorize("@ss.hasPermi('ems/base:emsAlarmActionStep:add')")
    @Log(title = "报警规则具体措施步骤", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody EmsAlarmActionStep emsAlarmActionStep)
    {
        emsAlarmActionStep.setCreateBy(getUsername());
        return toAjax(emsAlarmActionStepService.insertEmsAlarmActionStep(emsAlarmActionStep));
    }

    /**
     * 修改报警规则具体措施步骤
     */
    @PreAuthorize("@ss.hasPermi('ems/base:emsAlarmActionStep:edit')")
    @Log(title = "报警规则具体措施步骤", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody EmsAlarmActionStep emsAlarmActionStep)
    {
        emsAlarmActionStep.setUpdateBy(getUsername());
        return toAjax(emsAlarmActionStepService.updateEmsAlarmActionStep(emsAlarmActionStep));
    }

    /**
     * 删除报警规则具体措施步骤
     */
    @PreAuthorize("@ss.hasPermi('ems/base:emsAlarmActionStep:remove')")
    @Log(title = "报警规则具体措施步骤", businessType = BusinessType.DELETE)
	@DeleteMapping("/{objIds}")
    public AjaxResult remove(@PathVariable String[] objIds)
    {
        return toAjax(emsAlarmActionStepService.deleteEmsAlarmActionStepByObjIds(objIds));
    }

    /**
     * 根据报警数据信息查询对应的措施步骤列表
     */
    @PreAuthorize("@ss.hasPermi('ems/base:emsAlarmActionStep:query')")
    @GetMapping(value = "/alarm/{monitorId}/{cause}")
    public AjaxResult getStepsByAlarmInfo(@PathVariable("monitorId") String monitorId, @PathVariable("cause") String cause)
    {
        List<EmsAlarmActionStep> steps = emsAlarmActionStepService.selectActionStepsByAlarmInfo(monitorId, cause);
        return success(steps);
    }

    /**
     * 根据报警数据信息查询对应的措施步骤列表（POST方式，避免URL编码问题）
     */
    @PreAuthorize("@ss.hasPermi('ems/base:emsAlarmActionStep:query')")
    @PostMapping(value = "/getByAlarmInfo")
    public AjaxResult getStepsByAlarmInfoPost(@RequestBody Map<String, String> params)
    {
        String monitorId = params.get("monitorId");
        String cause = params.get("cause");
        
        if (monitorId == null || cause == null) {
            return error("参数不能为空：monitorId=" + monitorId + ", cause=" + cause);
        }
        
        List<EmsAlarmActionStep> steps = emsAlarmActionStepService.selectActionStepsByAlarmInfo(monitorId, cause);
        return success(steps);
    }

    /**
     * 批量保存措施步骤（包含图片信息）
     */
    @PreAuthorize("@ss.hasPermi('ems/base:emsAlarmActionStep:edit')")
    @Log(title = "批量保存措施步骤", businessType = BusinessType.UPDATE)
    @PostMapping(value = "/batchSave/{ruleObjId}")
    public AjaxResult batchSaveActionSteps(@PathVariable("ruleObjId") String ruleObjId, @RequestBody List<EmsAlarmActionStep> stepList)
    {
        return toAjax(emsAlarmActionStepService.batchSaveActionSteps(ruleObjId, stepList));
    }
}
