package com.os.ems.info.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.os.common.annotation.Log;
import com.os.common.core.controller.BaseController;
import com.os.common.core.domain.AjaxResult;
import com.os.common.enums.BusinessType;
import com.os.ems.info.domain.FaultHandlingRecord;
import com.os.ems.info.service.IFaultHandlingRecordService;
import com.os.common.utils.poi.ExcelUtil;
import com.os.common.core.page.TableDataInfo;
import org.springframework.web.multipart.MultipartFile;

/**
 * 故障处置记录Controller
 * 
 * @author Yinq
 * @date 2025-06-05
 */
@RestController
@RequestMapping("/ems/info/faultHandlingRecord")
public class FaultHandlingRecordController extends BaseController
{
    @Autowired
    private IFaultHandlingRecordService faultHandlingRecordService;

    /**
     * 查询故障处置记录列表
     */
    @PreAuthorize("@ss.hasPermi('ems/info:faultHandlingRecord:list')")
    @GetMapping("/list")
    public TableDataInfo list(FaultHandlingRecord faultHandlingRecord)
    {
        startPage();
        List<FaultHandlingRecord> list = faultHandlingRecordService.selectFaultHandlingRecordList(faultHandlingRecord);
        return getDataTable(list);
    }

    /**
     * 导出故障处置记录列表
     */
    @PreAuthorize("@ss.hasPermi('ems/info:faultHandlingRecord:export')")
    @Log(title = "故障处置记录", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, FaultHandlingRecord faultHandlingRecord)
    {
        List<FaultHandlingRecord> list = faultHandlingRecordService.selectFaultHandlingRecordList(faultHandlingRecord);
        ExcelUtil<FaultHandlingRecord> util = new ExcelUtil<FaultHandlingRecord>(FaultHandlingRecord.class);
        util.exportExcel(response, list, "故障处置记录数据");
    }

    /**
     * 获取故障处置记录详细信息
     */
    @PreAuthorize("@ss.hasPermi('ems/info:faultHandlingRecord:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(faultHandlingRecordService.selectFaultHandlingRecordById(id));
    }

    /**
     * 新增故障处置记录
     */
    @PreAuthorize("@ss.hasPermi('ems/info:faultHandlingRecord:add')")
    @Log(title = "故障处置记录", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody FaultHandlingRecord faultHandlingRecord)
    {
        faultHandlingRecord.setCreateBy(getUsername());
        return toAjax(faultHandlingRecordService.insertFaultHandlingRecord(faultHandlingRecord));
    }

    /**
     * 修改故障处置记录
     */
    @PreAuthorize("@ss.hasPermi('ems/info:faultHandlingRecord:edit')")
    @Log(title = "故障处置记录", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody FaultHandlingRecord faultHandlingRecord)
    {
        faultHandlingRecord.setUpdateBy(getUsername());
        return toAjax(faultHandlingRecordService.updateFaultHandlingRecord(faultHandlingRecord));
    }

    /**
     * 删除故障处置记录
     */
    @PreAuthorize("@ss.hasPermi('ems/info:faultHandlingRecord:remove')")
    @Log(title = "故障处置记录", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(faultHandlingRecordService.deleteFaultHandlingRecordByIds(ids));
    }

    /**
     * 导入故障处置记录数据
     */
    @PreAuthorize("@ss.hasPermi('ems/info:faultHandlingRecord:add')")
    @Log(title = "故障处置记录", businessType = BusinessType.IMPORT)
    @PostMapping("/importData")
    public AjaxResult importData(MultipartFile file, boolean updateSupport) throws Exception
    {
        ExcelUtil<FaultHandlingRecord> util = new ExcelUtil<FaultHandlingRecord>(FaultHandlingRecord.class);
        List<FaultHandlingRecord> recordList = util.importExcel(file.getInputStream());
        String operName = getUsername();
        String message = faultHandlingRecordService.importFaultHandlingRecord(recordList, updateSupport, operName);
        return AjaxResult.success(message);
    }

    /**
     * 获取故障处置记录导入模板
     */
    @PostMapping("/importTemplate")
    public AjaxResult importTemplate()
    {
        ExcelUtil<FaultHandlingRecord> util = new ExcelUtil<FaultHandlingRecord>(FaultHandlingRecord.class);
        return util.importTemplateExcel("故障处置记录数据");
    }
}
