package com.os.ems.info.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.multipart.MultipartFile;
import com.os.common.annotation.Log;
import com.os.common.core.controller.BaseController;
import com.os.common.core.domain.AjaxResult;
import com.os.common.enums.BusinessType;
import com.os.ems.info.domain.LuggageSystemSecurityDoorBatteryLifecycle;
import com.os.ems.info.service.ILuggageSystemSecurityDoorBatteryLifecycleService;
import com.os.common.utils.poi.ExcelUtil;
import com.os.common.core.page.TableDataInfo;

/**
 * 行李系统安全门铅酸电池生命周期Controller
 * 
 * @author Yinq
 * @date 2025-06-05
 */
@RestController
@RequestMapping("/ems/info/securityDoorBatteryLifecycle")
public class LuggageSystemSecurityDoorBatteryLifecycleController extends BaseController
{
    @Autowired
    private ILuggageSystemSecurityDoorBatteryLifecycleService luggageSystemSecurityDoorBatteryLifecycleService;

    /**
     * 查询行李系统安全门铅酸电池生命周期列表
     */
    @PreAuthorize("@ss.hasPermi('ems/info:securityDoorBatteryLifecycle:list')")
    @GetMapping("/list")
    public TableDataInfo list(LuggageSystemSecurityDoorBatteryLifecycle luggageSystemSecurityDoorBatteryLifecycle)
    {
        startPage();
        List<LuggageSystemSecurityDoorBatteryLifecycle> list = luggageSystemSecurityDoorBatteryLifecycleService.selectLuggageSystemSecurityDoorBatteryLifecycleList(luggageSystemSecurityDoorBatteryLifecycle);
        return getDataTable(list);
    }

    /**
     * 导出行李系统安全门铅酸电池生命周期列表
     */
    @PreAuthorize("@ss.hasPermi('ems/info:securityDoorBatteryLifecycle:export')")
    @Log(title = "行李系统安全门铅酸电池生命周期", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, LuggageSystemSecurityDoorBatteryLifecycle luggageSystemSecurityDoorBatteryLifecycle)
    {
        List<LuggageSystemSecurityDoorBatteryLifecycle> list = luggageSystemSecurityDoorBatteryLifecycleService.selectLuggageSystemSecurityDoorBatteryLifecycleList(luggageSystemSecurityDoorBatteryLifecycle);
        ExcelUtil<LuggageSystemSecurityDoorBatteryLifecycle> util = new ExcelUtil<LuggageSystemSecurityDoorBatteryLifecycle>(LuggageSystemSecurityDoorBatteryLifecycle.class);
        util.exportExcel(response, list, "行李系统安全门铅酸电池生命周期数据");
    }

    /**
     * 获取行李系统安全门铅酸电池生命周期详细信息
     */
    @PreAuthorize("@ss.hasPermi('ems/info:securityDoorBatteryLifecycle:query')")
    @GetMapping(value = "/{objid}")
    public AjaxResult getInfo(@PathVariable("objid") Long objid)
    {
        return success(luggageSystemSecurityDoorBatteryLifecycleService.selectLuggageSystemSecurityDoorBatteryLifecycleByObjid(objid));
    }

    /**
     * 新增行李系统安全门铅酸电池生命周期
     */
    @PreAuthorize("@ss.hasPermi('ems/info:securityDoorBatteryLifecycle:add')")
    @Log(title = "行李系统安全门铅酸电池生命周期", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody LuggageSystemSecurityDoorBatteryLifecycle luggageSystemSecurityDoorBatteryLifecycle)
    {
        luggageSystemSecurityDoorBatteryLifecycle.setCreateBy(getUsername());
        return toAjax(luggageSystemSecurityDoorBatteryLifecycleService.insertLuggageSystemSecurityDoorBatteryLifecycle(luggageSystemSecurityDoorBatteryLifecycle));
    }

    /**
     * 修改行李系统安全门铅酸电池生命周期
     */
    @PreAuthorize("@ss.hasPermi('ems/info:securityDoorBatteryLifecycle:edit')")
    @Log(title = "行李系统安全门铅酸电池生命周期", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody LuggageSystemSecurityDoorBatteryLifecycle luggageSystemSecurityDoorBatteryLifecycle)
    {
        luggageSystemSecurityDoorBatteryLifecycle.setUpdateBy(getUsername());
        return toAjax(luggageSystemSecurityDoorBatteryLifecycleService.updateLuggageSystemSecurityDoorBatteryLifecycle(luggageSystemSecurityDoorBatteryLifecycle));
    }

    /**
     * 删除行李系统安全门铅酸电池生命周期
     */
    @PreAuthorize("@ss.hasPermi('ems/info:securityDoorBatteryLifecycle:remove')")
    @Log(title = "行李系统安全门铅酸电池生命周期", businessType = BusinessType.DELETE)
	@DeleteMapping("/{objids}")
    public AjaxResult remove(@PathVariable Long[] objids)
    {
        return toAjax(luggageSystemSecurityDoorBatteryLifecycleService.deleteLuggageSystemSecurityDoorBatteryLifecycleByObjids(objids));
    }

    /**
     * 导入行李系统安全门铅酸电池生命周期数据
     */
    @PreAuthorize("@ss.hasPermi('ems/info:securityDoorBatteryLifecycle:add')")
    @Log(title = "行李系统安全门铅酸电池生命周期", businessType = BusinessType.IMPORT)
    @PostMapping("/importData")
    public AjaxResult importData(MultipartFile file, @RequestParam(value = "updateSupport", defaultValue = "false") boolean updateSupport) throws Exception
    {
        ExcelUtil<LuggageSystemSecurityDoorBatteryLifecycle> util = new ExcelUtil<LuggageSystemSecurityDoorBatteryLifecycle>(LuggageSystemSecurityDoorBatteryLifecycle.class);
        List<LuggageSystemSecurityDoorBatteryLifecycle> dataList = util.importExcel(file.getInputStream());
        String message = luggageSystemSecurityDoorBatteryLifecycleService.importLuggageSystemSecurityDoorBatteryLifecycle(dataList, updateSupport, getUsername());
        return AjaxResult.success(message);
    }

    /**
     * 获取行李系统安全门铅酸电池生命周期导入模板
     */
    @PreAuthorize("@ss.hasPermi('ems/info:securityDoorBatteryLifecycle:add')")
    @PostMapping("/importTemplate")
    public AjaxResult importTemplate()
    {
        ExcelUtil<LuggageSystemSecurityDoorBatteryLifecycle> util = new ExcelUtil<LuggageSystemSecurityDoorBatteryLifecycle>(LuggageSystemSecurityDoorBatteryLifecycle.class);
        return util.importTemplateExcel("行李系统安全门铅酸电池生命周期数据");
    }
}
