package com.os.ems.info.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.multipart.MultipartFile;
import com.os.common.annotation.Log;
import com.os.common.core.controller.BaseController;
import com.os.common.core.domain.AjaxResult;
import com.os.common.enums.BusinessType;
import com.os.ems.info.domain.PowerEnergySupervisionChecklist;
import com.os.ems.info.service.IPowerEnergySupervisionChecklistService;
import com.os.common.utils.poi.ExcelUtil;
import com.os.common.core.page.TableDataInfo;

/**
 * 动力能源部监督检查清单Controller
 * 
 * @author Yinq
 * @date 2025-06-05
 */
@RestController
@RequestMapping("/ems/info/supervisionChecklist")
public class PowerEnergySupervisionChecklistController extends BaseController
{
    @Autowired
    private IPowerEnergySupervisionChecklistService powerEnergySupervisionChecklistService;

    /**
     * 查询动力能源部监督检查清单列表
     */
    @PreAuthorize("@ss.hasPermi('ems/info:supervisionChecklist:list')")
    @GetMapping("/list")
    public TableDataInfo list(PowerEnergySupervisionChecklist powerEnergySupervisionChecklist)
    {
        startPage();
        List<PowerEnergySupervisionChecklist> list = powerEnergySupervisionChecklistService.selectPowerEnergySupervisionChecklistList(powerEnergySupervisionChecklist);
        return getDataTable(list);
    }

    /**
     * 导出动力能源部监督检查清单列表
     */
    @PreAuthorize("@ss.hasPermi('ems/info:supervisionChecklist:export')")
    @Log(title = "动力能源部监督检查清单", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, PowerEnergySupervisionChecklist powerEnergySupervisionChecklist)
    {
        List<PowerEnergySupervisionChecklist> list = powerEnergySupervisionChecklistService.selectPowerEnergySupervisionChecklistList(powerEnergySupervisionChecklist);
        ExcelUtil<PowerEnergySupervisionChecklist> util = new ExcelUtil<PowerEnergySupervisionChecklist>(PowerEnergySupervisionChecklist.class);
        util.exportExcel(response, list, "动力能源部监督检查清单数据");
    }

    /**
     * 获取动力能源部监督检查清单详细信息
     */
    @PreAuthorize("@ss.hasPermi('ems/info:supervisionChecklist:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(powerEnergySupervisionChecklistService.selectPowerEnergySupervisionChecklistById(id));
    }

    /**
     * 新增动力能源部监督检查清单
     */
    @PreAuthorize("@ss.hasPermi('ems/info:supervisionChecklist:add')")
    @Log(title = "动力能源部监督检查清单", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody PowerEnergySupervisionChecklist powerEnergySupervisionChecklist)
    {
        powerEnergySupervisionChecklist.setCreateBy(getUsername());
        return toAjax(powerEnergySupervisionChecklistService.insertPowerEnergySupervisionChecklist(powerEnergySupervisionChecklist));
    }

    /**
     * 修改动力能源部监督检查清单
     */
    @PreAuthorize("@ss.hasPermi('ems/info:supervisionChecklist:edit')")
    @Log(title = "动力能源部监督检查清单", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody PowerEnergySupervisionChecklist powerEnergySupervisionChecklist)
    {
        powerEnergySupervisionChecklist.setUpdateBy(getUsername());
        return toAjax(powerEnergySupervisionChecklistService.updatePowerEnergySupervisionChecklist(powerEnergySupervisionChecklist));
    }

    /**
     * 删除动力能源部监督检查清单
     */
    @PreAuthorize("@ss.hasPermi('ems/info:supervisionChecklist:remove')")
    @Log(title = "动力能源部监督检查清单", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(powerEnergySupervisionChecklistService.deletePowerEnergySupervisionChecklistByIds(ids));
    }

    /**
     * 下载模板
     */
    @PostMapping("/importTemplate")
    public void importTemplate(HttpServletResponse response)
    {
        ExcelUtil<PowerEnergySupervisionChecklist> util = new ExcelUtil<PowerEnergySupervisionChecklist>(PowerEnergySupervisionChecklist.class);
        util.importTemplateExcel(response, "动力能源部监督检查清单数据");
    }

    /**
     * 导入数据
     */
    @Log(title = "动力能源部监督检查清单", businessType = BusinessType.IMPORT)
    @PreAuthorize("@ss.hasPermi('ems/info:supervisionChecklist:add')")
    @PostMapping("/importData")
    public AjaxResult importData(MultipartFile file, boolean updateSupport) throws Exception
    {
        ExcelUtil<PowerEnergySupervisionChecklist> util = new ExcelUtil<PowerEnergySupervisionChecklist>(PowerEnergySupervisionChecklist.class);
        List<PowerEnergySupervisionChecklist> recordList = util.importExcel(file.getInputStream());
        String operName = getUsername();
        String message = powerEnergySupervisionChecklistService.importPowerEnergySupervisionChecklist(recordList, updateSupport, operName);
        return success(message);
    }
}
