package com.os.ems.info.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.multipart.MultipartFile;
import com.os.common.annotation.Log;
import com.os.common.core.controller.BaseController;
import com.os.common.core.domain.AjaxResult;
import com.os.common.enums.BusinessType;
import com.os.ems.info.domain.SparePartsUsageRecord;
import com.os.ems.info.service.ISparePartsUsageRecordService;
import com.os.common.utils.poi.ExcelUtil;
import com.os.common.core.page.TableDataInfo;

/**
 * 动力能源部行输科备件领用更换记录Controller
 * 
 * @author Yinq
 * @date 2025-06-05
 */
@RestController
@RequestMapping("/ems/info/sparePartsUsageRecord")
public class SparePartsUsageRecordController extends BaseController
{
    @Autowired
    private ISparePartsUsageRecordService sparePartsUsageRecordService;

    /**
     * 查询动力能源部行输科备件领用更换记录列表
     */
    @PreAuthorize("@ss.hasPermi('ems/info:sparePartsUsageRecord:list')")
    @GetMapping("/list")
    public TableDataInfo list(SparePartsUsageRecord sparePartsUsageRecord)
    {
        startPage();
        List<SparePartsUsageRecord> list = sparePartsUsageRecordService.selectSparePartsUsageRecordList(sparePartsUsageRecord);
        return getDataTable(list);
    }

    /**
     * 导出动力能源部行输科备件领用更换记录列表
     */
    @PreAuthorize("@ss.hasPermi('ems/info:sparePartsUsageRecord:export')")
    @Log(title = "动力能源部行输科备件领用更换记录", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, SparePartsUsageRecord sparePartsUsageRecord)
    {
        List<SparePartsUsageRecord> list = sparePartsUsageRecordService.selectSparePartsUsageRecordList(sparePartsUsageRecord);
        ExcelUtil<SparePartsUsageRecord> util = new ExcelUtil<SparePartsUsageRecord>(SparePartsUsageRecord.class);
        util.exportExcel(response, list, "动力能源部行输科备件领用更换记录数据");
    }

    /**
     * 获取动力能源部行输科备件领用更换记录详细信息
     */
    @PreAuthorize("@ss.hasPermi('ems/info:sparePartsUsageRecord:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(sparePartsUsageRecordService.selectSparePartsUsageRecordById(id));
    }

    /**
     * 新增动力能源部行输科备件领用更换记录
     */
    @PreAuthorize("@ss.hasPermi('ems/info:sparePartsUsageRecord:add')")
    @Log(title = "动力能源部行输科备件领用更换记录", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody SparePartsUsageRecord sparePartsUsageRecord)
    {
        sparePartsUsageRecord.setCreateBy(getUsername());
        return toAjax(sparePartsUsageRecordService.insertSparePartsUsageRecord(sparePartsUsageRecord));
    }

    /**
     * 修改动力能源部行输科备件领用更换记录
     */
    @PreAuthorize("@ss.hasPermi('ems/info:sparePartsUsageRecord:edit')")
    @Log(title = "动力能源部行输科备件领用更换记录", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody SparePartsUsageRecord sparePartsUsageRecord)
    {
        sparePartsUsageRecord.setUpdateBy(getUsername());
        return toAjax(sparePartsUsageRecordService.updateSparePartsUsageRecord(sparePartsUsageRecord));
    }

    /**
     * 删除动力能源部行输科备件领用更换记录
     */
    @PreAuthorize("@ss.hasPermi('ems/info:sparePartsUsageRecord:remove')")
    @Log(title = "动力能源部行输科备件领用更换记录", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(sparePartsUsageRecordService.deleteSparePartsUsageRecordByIds(ids));
    }

    /**
     * 导入动力能源部行输科备件领用更换记录数据
     */
    @PreAuthorize("@ss.hasPermi('ems/info:sparePartsUsageRecord:add')")
    @Log(title = "动力能源部行输科备件领用更换记录", businessType = BusinessType.IMPORT)
    @PostMapping("/importData")
    public AjaxResult importData(MultipartFile file, boolean updateSupport) throws Exception
    {
        ExcelUtil<SparePartsUsageRecord> util = new ExcelUtil<SparePartsUsageRecord>(SparePartsUsageRecord.class);
        List<SparePartsUsageRecord> recordList = util.importExcel(file.getInputStream());
        String operName = getUsername();
        String message = sparePartsUsageRecordService.importSparePartsUsageRecord(recordList, updateSupport, operName);
        return AjaxResult.success(message);
    }

    /**
     * 获取动力能源部行输科备件领用更换记录导入模板
     */
    @PostMapping("/importTemplate")
    public AjaxResult importTemplate()
    {
        ExcelUtil<SparePartsUsageRecord> util = new ExcelUtil<SparePartsUsageRecord>(SparePartsUsageRecord.class);
        return util.importTemplateExcel("动力能源部行输科备件领用更换记录数据");
    }
}
