package com.os.ems.record.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.os.common.annotation.Log;
import com.os.common.core.controller.BaseController;
import com.os.common.core.domain.AjaxResult;
import com.os.common.enums.BusinessType;
import com.os.ems.record.domain.EmsVibrationInstant;
import com.os.ems.record.service.IEmsVibrationInstantService;
import com.os.common.utils.poi.ExcelUtil;
import com.os.common.core.page.TableDataInfo;

/**
 * 震动实时数据Controller
 * 
 * @author ZangCH
 * @date 2024-08-22
 */
@RestController
@RequestMapping("/ems/record/recordVibrationInstant")
public class EmsVibrationInstantController extends BaseController
{
    @Autowired
    private IEmsVibrationInstantService emsVibrationInstantService;

    /**
     * 查询震动实时数据列表
     */
    @PreAuthorize("@ss.hasPermi('ems/record:recordVibrationInstant:list')")
    @GetMapping("/list")
    public TableDataInfo list(EmsVibrationInstant emsVibrationInstant)
    {
        startPage();
        List<EmsVibrationInstant> list = emsVibrationInstantService.selectEmsVibrationInstantList(emsVibrationInstant);
        return getDataTable(list);
    }

    /**
     * 导出震动实时数据列表
     */
    @PreAuthorize("@ss.hasPermi('ems/record:recordVibrationInstant:export')")
    @Log(title = "震动实时数据", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, EmsVibrationInstant emsVibrationInstant)
    {
        List<EmsVibrationInstant> list = emsVibrationInstantService.selectEmsVibrationInstantList(emsVibrationInstant);
        ExcelUtil<EmsVibrationInstant> util = new ExcelUtil<EmsVibrationInstant>(EmsVibrationInstant.class);
        util.exportExcel(response, list, "震动实时数据数据");
    }

    /**
     * 获取震动实时数据详细信息
     */
    @PreAuthorize("@ss.hasPermi('ems/record:recordVibrationInstant:query')")
    @GetMapping(value = "/{objId}")
    public AjaxResult getInfo(@PathVariable("objId") Long objId)
    {
        return success(emsVibrationInstantService.selectEmsVibrationInstantByObjId(objId));
    }

    /**
     * 新增震动实时数据
     */
    @PreAuthorize("@ss.hasPermi('ems/record:recordVibrationInstant:add')")
    @Log(title = "震动实时数据", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody EmsVibrationInstant emsVibrationInstant)
    {
        emsVibrationInstant.setCreateBy(getUsername());
        return toAjax(emsVibrationInstantService.insertEmsVibrationInstant(emsVibrationInstant));
    }

    /**
     * 修改震动实时数据
     */
    @PreAuthorize("@ss.hasPermi('ems/record:recordVibrationInstant:edit')")
    @Log(title = "震动实时数据", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody EmsVibrationInstant emsVibrationInstant)
    {
        emsVibrationInstant.setUpdateBy(getUsername());
        return toAjax(emsVibrationInstantService.updateEmsVibrationInstant(emsVibrationInstant));
    }

    /**
     * 删除震动实时数据
     */
    @PreAuthorize("@ss.hasPermi('ems/record:recordVibrationInstant:remove')")
    @Log(title = "震动实时数据", businessType = BusinessType.DELETE)
	@DeleteMapping("/{objIds}")
    public AjaxResult remove(@PathVariable Long[] objIds)
    {
        return toAjax(emsVibrationInstantService.deleteEmsVibrationInstantByObjIds(objIds));
    }

    /**
     * 查询震动实时数据
     * @param emsVibrationInstant
     * @return
     */
    @GetMapping("/vibrationInstantList")
    public AjaxResult vibrationInstantList(EmsVibrationInstant emsVibrationInstant) {
        List<EmsVibrationInstant> list = emsVibrationInstantService
                .selectVibrationInstantList(emsVibrationInstant);
        return success(list);
    }
}
