package com.os.mes.base.service.impl;

import java.util.List;

import com.os.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.os.mes.base.mapper.BaseProductLineMapper;
import com.os.mes.base.domain.BaseProductLine;
import com.os.mes.base.service.IBaseProductLineService;

/**
 * 产线/工位信息Service业务层处理
 * 
 * @author Yinq
 * @date 2024-05-10
 */
@Service
public class BaseProductLineServiceImpl implements IBaseProductLineService 
{
    @Autowired
    private BaseProductLineMapper baseProductLineMapper;

    /**
     * 查询产线/工位信息
     * 
     * @param objId 产线/工位信息主键
     * @return 产线/工位信息
     */
    @Override
    public BaseProductLine selectBaseProductLineByObjId(Long objId)
    {
        return baseProductLineMapper.selectBaseProductLineByObjId(objId);
    }

    /**
     * 查询产线/工位信息列表
     * 
     * @param baseProductLine 产线/工位信息
     * @return 产线/工位信息
     */
    @Override
    public List<BaseProductLine> selectBaseProductLineList(BaseProductLine baseProductLine)
    {
        return baseProductLineMapper.selectBaseProductLineList(baseProductLine);
    }

    /**
     * 新增产线/工位信息
     * 
     * @param baseProductLine 产线/工位信息
     * @return 结果
     */
    @Override
    public int insertBaseProductLine(BaseProductLine baseProductLine)
    {
        baseProductLine.setCreateTime(DateUtils.getNowDate());
        return baseProductLineMapper.insertBaseProductLine(baseProductLine);
    }

    /**
     * 修改产线/工位信息
     * 
     * @param baseProductLine 产线/工位信息
     * @return 结果
     */
    @Override
    public int updateBaseProductLine(BaseProductLine baseProductLine)
    {
        baseProductLine.setUpdateTime(DateUtils.getNowDate());
        return baseProductLineMapper.updateBaseProductLine(baseProductLine);
    }

    /**
     * 批量删除产线/工位信息
     * 
     * @param objIds 需要删除的产线/工位信息主键
     * @return 结果
     */
    @Override
    public int deleteBaseProductLineByObjIds(Long[] objIds)
    {
        return baseProductLineMapper.deleteBaseProductLineByObjIds(objIds);
    }

    /**
     * 删除产线/工位信息信息
     * 
     * @param objId 产线/工位信息主键
     * @return 结果
     */
    @Override
    public int deleteBaseProductLineByObjId(Long objId)
    {
        return baseProductLineMapper.deleteBaseProductLineByObjId(objId);
    }
}
