package com.os.mes.prod.domain;

import java.math.BigDecimal;
import java.util.Date;

import com.fasterxml.jackson.annotation.JsonFormat;
import org.apache.commons.lang3.builder.ToStringBuilder;
import org.apache.commons.lang3.builder.ToStringStyle;
import com.os.common.annotation.Excel;
import com.os.common.core.domain.BaseEntity;

/**
 * 工单明细对象 prod_plan_detail
 *
 * @author Yinq
 * @date 2024-07-08
 */
public class ProdPlanDetail extends BaseEntity {
    private static final long serialVersionUID = 1L;

    /**
     * 主键标识
     */
    private Long objId;

    /**
     * 工单编号
     */
    @Excel(name = "工单编号")
    private String planCode;

    /**
     * 物料编号
     */
    @Excel(name = "物料编号")
    private String materialCode;

    /**
     * 计划数量
     */
    @Excel(name = "计划数量")
    private BigDecimal planAmount;

    /**
     * 完成数量
     */
    @Excel(name = "完成数量")
    private BigDecimal completeAmount;

    /**
     * 实际开始时间
     */
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @Excel(name = "实际开始时间", width = 30, dateFormat = "yyyy-MM-dd HH:mm:ss")
    private Date beginTime;

    /**
     * 实际完成时间
     */
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @Excel(name = "实际完成时间", width = 30, dateFormat = "yyyy-MM-dd HH:mm:ss")
    private Date endTime;

    /**
     * 当前班组班长
     */
    @Excel(name = "当前班组班长")
    private String currentStaffId;

    /**
     * 下一班组班长
     */
    @Excel(name = "下一班组班长")
    private String nextStaffId;

    /**
     * 是否标识
     */
    @Excel(name = "是否标识")
    private String endFlag;

    /**
     * 创建人
     */
    @Excel(name = "创建人")
    private String createdBy;

    /**
     * 创建时间
     */
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @Excel(name = "创建时间", width = 30, dateFormat = "yyyy-MM-dd HH:mm:ss")
    private Date createdTime;

    /**
     * 更新人
     */
    @Excel(name = "更新人")
    private String updatedBy;

    /**
     * 更新时间
     */
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @Excel(name = "更新时间", width = 30, dateFormat = "yyyy-MM-dd HH:mm:ss")
    private Date updatedTime;

    /**
     * 班次（1早班 2小夜 3大夜）
     */
    @Excel(name = "班次", readConverterExp = "1=早班,2=小夜,3=大夜")
    private String classes;

    /**
     * 工序编号
     */
    @Excel(name = "工序编号")
    private String processCode;

    public void setObjId(Long objId) {
        this.objId = objId;
    }

    public Long getObjId() {
        return objId;
    }

    public void setPlanCode(String planCode) {
        this.planCode = planCode;
    }

    public String getPlanCode() {
        return planCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }

    public String getMaterialCode() {
        return materialCode;
    }

    public void setPlanAmount(BigDecimal planAmount) {
        this.planAmount = planAmount;
    }

    public BigDecimal getPlanAmount() {
        return planAmount;
    }

    public void setCompleteAmount(BigDecimal completeAmount) {
        this.completeAmount = completeAmount;
    }

    public BigDecimal getCompleteAmount() {
        return completeAmount;
    }

    public void setBeginTime(Date beginTime) {
        this.beginTime = beginTime;
    }

    public Date getBeginTime() {
        return beginTime;
    }

    public void setEndTime(Date endTime) {
        this.endTime = endTime;
    }

    public Date getEndTime() {
        return endTime;
    }

    public void setCurrentStaffId(String currentStaffId) {
        this.currentStaffId = currentStaffId;
    }

    public String getCurrentStaffId() {
        return currentStaffId;
    }

    public void setNextStaffId(String nextStaffId) {
        this.nextStaffId = nextStaffId;
    }

    public String getNextStaffId() {
        return nextStaffId;
    }

    public void setEndFlag(String endFlag) {
        this.endFlag = endFlag;
    }

    public String getEndFlag() {
        return endFlag;
    }

    public void setCreatedBy(String createdBy) {
        this.createdBy = createdBy;
    }

    public String getCreatedBy() {
        return createdBy;
    }

    public void setCreatedTime(Date createdTime) {
        this.createdTime = createdTime;
    }

    public Date getCreatedTime() {
        return createdTime;
    }

    public void setUpdatedBy(String updatedBy) {
        this.updatedBy = updatedBy;
    }

    public String getUpdatedBy() {
        return updatedBy;
    }

    public void setUpdatedTime(Date updatedTime) {
        this.updatedTime = updatedTime;
    }

    public Date getUpdatedTime() {
        return updatedTime;
    }

    public void setClasses(String classes) {
        this.classes = classes;
    }

    public String getClasses() {
        return classes;
    }

    public void setProcessCode(String processCode) {
        this.processCode = processCode;
    }

    public String getProcessCode() {
        return processCode;
    }

    @Override
    public String toString() {
        return new ToStringBuilder(this, ToStringStyle.MULTI_LINE_STYLE)
                .append("objId", getObjId())
                .append("planCode", getPlanCode())
                .append("materialCode", getMaterialCode())
                .append("planAmount", getPlanAmount())
                .append("completeAmount", getCompleteAmount())
                .append("beginTime", getBeginTime())
                .append("endTime", getEndTime())
                .append("currentStaffId", getCurrentStaffId())
                .append("nextStaffId", getNextStaffId())
                .append("endFlag", getEndFlag())
                .append("createdBy", getCreatedBy())
                .append("createdTime", getCreatedTime())
                .append("updatedBy", getUpdatedBy())
                .append("updatedTime", getUpdatedTime())
                .append("classes", getClasses())
                .append("processCode", getProcessCode())
                .toString();
    }
}
