package com.os.mes.prod.service;

import java.util.HashMap;
import java.util.List;

import com.os.mes.api.domain.RecordData;
import com.os.mes.prod.domain.ProdOrderDetail;
import com.os.mes.prod.domain.ProdOrderInfo;
import com.os.mes.prod.domain.ProdPlanInfo;

/**
 * 订单信息Service接口
 *
 * @author Yinq
 * @date 2024-05-17
 */
public interface IProdOrderInfoService {
    /**
     * 查询订单信息
     *
     * @param objId 订单信息主键
     * @return 订单信息
     */
    public ProdOrderInfo selectProdOrderInfoByObjId(Long objId);

    /**
     * 查询订单信息列表
     *
     * @param prodOrderInfo 订单信息
     * @return 订单信息集合
     */
    public List<ProdOrderInfo> selectProdOrderInfoList(ProdOrderInfo prodOrderInfo);

    /**
     * 新增订单信息
     *
     * @param prodOrderInfo 订单信息
     * @return 结果
     */
    public int insertProdOrderInfo(ProdOrderInfo prodOrderInfo);

    /**
     * 修改订单信息
     *
     * @param prodOrderInfo 订单信息
     * @return 结果
     */
    public int updateProdOrderInfo(ProdOrderInfo prodOrderInfo);

    /**
     * 批量删除订单信息
     *
     * @param objIds 需要删除的订单信息主键集合
     * @return 结果
     */
    public int deleteProdOrderInfoByObjIds(Long[] objIds);

    /**
     * 删除订单信息信息
     *
     * @param objId 订单信息主键
     * @return 结果
     */
    public int deleteProdOrderInfoByObjId(Long objId);

    /**
     * 通过ERP插入订单信息
     * @param recordData
     */
    public ProdOrderDetail insertOrderByERP(RecordData recordData);

    /**
     * 根据订单生成工单
     * @param prodOrderInfo
     * @return
     */
    HashMap<String, Object> generateWorkOrder(ProdOrderInfo prodOrderInfo);

}
